<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xs="http://www.w3.org/2001/XMLSchema"
  exclude-result-prefixes="xs"
  version="2.0">
  
  <xsl:output indent="yes"/>
  
  <xsl:variable name="first-line" select="/text/line[.='INTRODUCTION'][1]"/>
  <!-- The first line containing "INTRODUCTION" is the header of the introduction. -->
  
  <xsl:variable name="last-line" select="/text/line[.='108']"/>
  <!-- The line containing '108' is the last line of the text. -->
  
  <!-- A number of lines can be scrubbed from the text in this pass. -->
  <xsl:template match="line[. &lt;&lt; $first-line]
                         (: We remove all lines before the first line of the
                            Introduction; we'll encode front matter by hand. :) |
                       line[.='INTRODUCTION'][not(. is $first-line)]
                         (: The Introduction contains page headers, which we remove. :) |
                       line[. = $scraps]
                         (: A number of lines are listed in $scraps, to be removed. :) |
                       line[. &gt;&gt; $last-line]
                         (: Lines after p. 108 contain only advertisements. :)"/>
  
  <!-- We'd also get rid of blank lines, except we can't, since some of them are
       significant (they demarcate paragraphs), but we can't assess which until this
       pass has removed all the others. -->
  
  <xsl:variable name="scraps" as="element()*">
    <!-- lists lines we designate for removal by hand; these include
         page headers and miscellaneous anomalies of scanning, etc. -->
    <line>INTRO D UCTION</line>
    <line>INTROD UCTION</line>
    <line>PREFACE</line>
    <line>APPENDIX, FIRST EDITION</line>
    <line>LIFE AFTER DEATH</line>
    <line>LIFE AFTER DEA TH</line>
    <line>LIFE AFTLrt DEATH</line>
    <line>--.</line>
    <line>b xvii</line>
  </xsl:variable>
  
  <xsl:template match="*">
    <xsl:copy>
      <xsl:copy-of select="@*"/>
      <xsl:apply-templates/>
    </xsl:copy>
  </xsl:template>
    
    
</xsl:stylesheet>