<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xs="http://www.w3.org/2001/XMLSchema"
  exclude-result-prefixes="xs"
  version="2.0">
  
  <xsl:output indent="yes"/>
  
  <!-- In this pass we group together lines within our divs into
       paragraphs, promoting the heads while doing so. We would have done
       all this in the previous pass, except promoting the heads is difficult
       before the divs are in place. -->
  
  <xsl:template match="div">
    <xsl:copy>
      <xsl:for-each-group select="*"
        group-ending-with="line[not(normalize-space(.))]">
        <!-- Within the div, we subgroup sets of lines ending with blank lines. -->
        <xsl:choose>
          <xsl:when test="position() eq 1">
            <head>
              <xsl:apply-templates select="current-group()[normalize-space(.)]"/>
              <!-- Since we no longer need the lines, we just write the value, making sure lines have
                whitespace between them (which can be cleaned up). -->
            </head>
          </xsl:when>
          <xsl:otherwise>
            <p>
              <xsl:apply-templates select="current-group()[normalize-space(.) or self::pb]"/>
            </p>
          </xsl:otherwise>
        </xsl:choose>

      </xsl:for-each-group>
    </xsl:copy>
  </xsl:template>
  
  <xsl:template match="line">
    <xsl:if test="position() ne 1">
      <xsl:text> </xsl:text>
    </xsl:if>
    <xsl:apply-templates/>
  </xsl:template>
  
  <xsl:template match="pb">
    <!-- copying the pb   -->
    <xsl:copy>
      <xsl:for-each select="following::pb[1]">
      <!-- *except* ... their @n is wrong, it should actually be the n on the next pb
      (since page footers appear at the bottom, not top of the page) -->
        <xsl:copy-of select="@n"/>
      </xsl:for-each>
    </xsl:copy>
  </xsl:template>
  
  <xsl:template match="*">
    <xsl:copy>
      <xsl:copy-of select="@*"/>
      <xsl:apply-templates/>
    </xsl:copy>
  </xsl:template>
    
    
</xsl:stylesheet>